function v=humdv(mr,t)
% humdv	 - Gives the specificvolume of humid air
% function v=humdv(mr,t)
% Argument List:
% Argument   Gives
%    mr     the mass ratio of water to dry air.
%    t      the temperature in units of Tdeg.
% v is the volume in cubic meters per kg of dry air.
ns=1000*[[.79 .21]/28.85264,mr/18.016];
v=at(t)*8.3143*sum(ns)/101350;
